@@ -9,6 +9,7 @@ import math
 import os
 import socket
 import logging
+import logging.handlers
 import struct
 import time
 import traceback
@@ -20,10 +21,27 @@ from threading import Lock, Thread
 from typing import Callable
 
 
+def initLogger(name: str, level=logging.DEBUG):
+    logger = logging.getLogger("sencyber")
+    LOG_FORMAT = "%(asctime)s [%(levelname)s]: %(message)s @ [%(module)s-%(lineno)s]"
+
+    handler = logging.handlers.RotatingFileHandler(
+        filename=f"{name}.log",
+        encoding="utf-8",
+        maxBytes=102400,
+        backupCount=10,
+    )
+    handler.setFormatter(logging.Formatter(LOG_FORMAT))
+
+    logger.addHandler(handler)
+    logger.setLevel(level)
+
+
 class PositionAHRS:
     """
     Position AHRS
     """
+
     def __init__(self):
         self.beta = 0
         self.pi = 0
@@ -117,6 +135,7 @@ class ConcurrentHandler:
     """
     Defined Concurrent Process Handler
     """
+
     def __init__(self, max_workers: int, call_back: Callable):
         self.__threadPool = ThreadPoolExecutor(max_workers=max_workers, thread_name_prefix="sencyber")
         self.__call_back = call_back
@@ -199,6 +218,7 @@ class SencyberLogger:
     """
     Defines a Logger using default python logger and send the logs to specific server
     """
+
     def __init__(self, receiver_address='0.0.0.0',
                  receiver_port=10080,
                  title='default',
@@ -222,7 +242,7 @@ class SencyberLogger:
             format=self.LOG_FORMAT,
         )
 
-        self.__root_logger = logging.getLogger()
+        self.__root_logger = logging.getLogger('sencyber_TEST')
 
         self.__handler = logging.FileHandler(filename=f"{self.file_name}.log", encoding="utf-8")
         self.__handler.setFormatter(logging.Formatter(self.LOG_FORMAT))
@@ -234,6 +254,9 @@ class SencyberLogger:
         self.__thread.start()
         logging.info(f"{self.title} Logger Initialization Complete.")
 
+    def get_logger(self) -> logging.Logger:
+        return self.__root_logger
+
     def sendLogging(self):
         logging.debug(f"Prepare to send logs...")
         if self.receiver_address == "0.0.0.0":
@@ -370,6 +393,7 @@ class SencyberLoggerReceiver:
     """
     Defines a Server For receiving the logs
     """
+
     def __init__(self, bind_address="0.0.0.0", bind_port=10080, path="./"):
         LOG_FORMAT = "%(asctime)s [%(levelname)s]: %(message)s @ [%(module)s-%(lineno)s]"
         logging.basicConfig(
